==> huaweicloudsdkcoc-3.1.120-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/public_script_list_page.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PublicScriptListPage:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'data': 'list[PublicScriptListModel]'
    }

    attribute_map = {
        'total': 'total',
        'data': 'data'
    }

    def __init__(self, total=None, data=None):
        """PublicScriptListPage

        The model defined in huaweicloud sdk

        :param total: 总条数
        :type total: int
        :param data: 单页数据列表
        :type data: list[:class:`huaweicloudsdkcoc.v1.PublicScriptListModel`]
        """
        
        

        self._total = None
        self._data = None
        self.discriminator = None

        self.total = total
        self.data = data

    @property
    def total(self):
        """Gets the total of this PublicScriptListPage.

        总条数

        :return: The total of this PublicScriptListPage.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this PublicScriptListPage.

        总条数

        :param total: The total of this PublicScriptListPage.
        :type total: int
        """
        self._total = total

    @property
    def data(self):
        """Gets the data of this PublicScriptListPage.

        单页数据列表

        :return: The data of this PublicScriptListPage.
        :rtype: list[:class:`huaweicloudsdkcoc.v1.PublicScriptListModel`]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this PublicScriptListPage.

        单页数据列表

        :param data: The data of this PublicScriptListPage.
        :type data: list[:class:`huaweicloudsdkcoc.v1.PublicScriptListModel`]
        """
        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicScriptListPage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcoc-3.1.144-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/public_script_list_page.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PublicScriptListPage:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'data': 'list[PublicScriptListModel]'
    }

    attribute_map = {
        'total': 'total',
        'data': 'data'
    }

    def __init__(self, total=None, data=None):
        r"""PublicScriptListPage

        The model defined in huaweicloud sdk

        :param total: 总条数
        :type total: int
        :param data: 单页数据列表
        :type data: list[:class:`huaweicloudsdkcoc.v1.PublicScriptListModel`]
        """
        
        

        self._total = None
        self._data = None
        self.discriminator = None

        self.total = total
        self.data = data

    @property
    def total(self):
        r"""Gets the total of this PublicScriptListPage.

        总条数

        :return: The total of this PublicScriptListPage.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        r"""Sets the total of this PublicScriptListPage.

        总条数

        :param total: The total of this PublicScriptListPage.
        :type total: int
        """
        self._total = total

    @property
    def data(self):
        r"""Gets the data of this PublicScriptListPage.

        单页数据列表

        :return: The data of this PublicScriptListPage.
        :rtype: list[:class:`huaweicloudsdkcoc.v1.PublicScriptListModel`]
        """
        return self._data

    @data.setter
    def data(self, data):
        r"""Sets the data of this PublicScriptListPage.

        单页数据列表

        :param data: The data of this PublicScriptListPage.
        :type data: list[:class:`huaweicloudsdkcoc.v1.PublicScriptListModel`]
        """
        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicScriptListPage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
